@@ -97,8 +97,6 @@ sub _generate_accessor{
         }
         elsif(defined $constraint){
             $accessor .= "my \$tmp = $value;\n";
-            #XXX: The following 'defined and' check is for backward compatibility
-            $accessor .= "defined(\$tmp) and ";
 
             $accessor .= "\$compiled_type_constraint->(\$tmp)";
             $accessor .= " || \$attribute->verify_type_constraint_error(\$name, \$tmp, \$constraint);\n";
@@ -175,7 +173,7 @@ Mouse::Meta::Method::Accessor - A Mouse method generator for accessors
 
 =head1 VERSION
 
-This document describes Mouse version 0.40_01
+This document describes Mouse version 0.40_02
 
 =head1 SEE ALSO
 
