@@ -3,8 +3,8 @@ use Mouse::Util qw/:meta get_code_package get_code_ref load_class not_supported/
 
 use Mouse::Util::TypeConstraints ();
 
-use Carp ();
-use Scalar::Util qw/blessed weaken/;
+use Carp         ();
+use Scalar::Util ();
 
 my %METAS;
 
@@ -69,55 +69,32 @@ sub get_attribute     {        $_[0]->{attributes}->{$_[1]} }
 sub get_attribute_list{ keys %{$_[0]->{attributes}}         }
 sub remove_attribute  { delete $_[0]->{attributes}->{$_[1]} }
 
-sub add_method {
-    my($self, $name, $code) = @_;
-
-    if(!defined $name){
-        $self->throw_error('You must pass a defined name');
-    }
-    if(!defined $code){
-        $self->throw_error('You must pass a defined code');
-    }
-
-    if(ref($code) ne 'CODE'){
-        $code = \&{$code}; # coerce
-    }
-
-    $self->{methods}->{$name} = $code; # Moose stores meta object here.
-
-    my $pkg = $self->name;
-    no strict 'refs';
-    no warnings 'redefine', 'once';
-    *{ $pkg . '::' . $name } = $code;
-}
-
 # XXX: for backward compatibility
 my %foreign = map{ $_ => undef } qw(
     Mouse Mouse::Role Mouse::Util Mouse::Util::TypeConstraints
-    Carp Scalar::Util
+    Carp Scalar::Util List::Util
 );
 sub _code_is_mine{
-    my($self, $code) = @_;
+#    my($self, $code) = @_;
 
-    my $package = get_code_package($code);
-
-    return !exists $foreign{$package};
+    return !exists $foreign{ get_code_package($_[1]) };
 }
 
+sub add_method;
+
 sub has_method {
     my($self, $method_name) = @_;
 
     defined($method_name)
         or $self->throw_error('You must define a method name');
 
-    return 1 if $self->{methods}{$method_name};
-
-    my $code = get_code_ref($self->{package}, $method_name);
-
-    return $code && $self->_code_is_mine($code);
+    return defined($self->{methods}{$method_name}) || do{
+        my $code = get_code_ref($self->{package}, $method_name);
+        $code && $self->_code_is_mine($code);
+    };
 }
 
-sub get_method_body{
+sub get_method_body {
     my($self, $method_name) = @_;
 
     defined($method_name)
@@ -125,19 +102,19 @@ sub get_method_body{
 
     return $self->{methods}{$method_name} ||= do{
         my $code = get_code_ref($self->{package}, $method_name);
-        ($code && $self->_code_is_mine($code)) ? $code : undef;
+        $code && $self->_code_is_mine($code) ? $code : undef;
     };
 }
 
 sub get_method{
     my($self, $method_name) = @_;
 
-    if($self->has_method($method_name)){
+    if(my $code = $self->get_method_body($method_name)){
         my $method_metaclass = $self->method_metaclass;
         load_class($method_metaclass);
 
         return $method_metaclass->wrap(
-            body                 => $self->get_method_body($method_name),
+            body                 => $code,
             name                 => $method_name,
             package              => $self->name,
             associated_metaclass => $self,
@@ -219,7 +196,7 @@ sub get_method_list {
 
         my $meta = $self->initialize( $package_name, %options);
 
-        weaken $METAS{$package_name}
+        Scalar::Util::weaken $METAS{$package_name}
             if $mortal;
 
         $meta->add_method(meta => sub{
@@ -313,7 +290,7 @@ Mouse::Meta::Module - The base class for Mouse::Meta::Class and Mouse::Meta::Rol
 
 =head1 VERSION
 
-This document describes Mouse version 0.40_01
+This document describes Mouse version 0.40_02
 
 =head1 SEE ALSO
 
